@@ -1,7 +1,8 @@
-import os,sys,unicodedata,hashlib,json
+import os,sys,unicodedata,hashlib,json,logging
 from flask_cors import CORS
 from abstract_utilities import make_list,get_media_types,get_logFile
 from multiprocessing import Process
+
 from flask import (
     Blueprint,
     request,
@@ -11,35 +12,41 @@ from flask import (
     Flask,
     redirect,
     send_from_directory,
-    abort
+    abort,
+    Flask,
+    has_request_context
     
 )
+from abstract_queries import USER_IP_MGR
+from .file_utils import *
+from .request_utils import *
+from .network_utils import *
 
-from .request_utils import (dump_if_json,
-                            required_keys,
-                            parse_request,
-                            parse_and_return_json,
-                            parse_and_spec_vars,
-                            get_only_kwargs
-                            )
-from .network_tools import get_user_ip
 from werkzeug.utils import secure_filename
+def get_from_kwargs(keys,**kwargs):
+    output_js = {}
+    for key in keys:
+        if key in kwargs:
+            output_js[key]= kwargs.get(key)
+            del kwargs[key]
+    return output_js,kwargs
+def get_name(name,abs_path=None):
+    if os.path.isfile(name):
+        basename = os.path.basename(name)
+        name = os.path.splitext(basename)[0]
+    abs_path = abs_path or __name__
+    return name,abs_path
 def jsonify_it(obj):
     if isinstance(obj,dict):
         status_code = obj.get("status_code")
         return jsonify(obj),status_code
 def get_bp(name,abs_path=None, **bp_kwargs):
     # if they passed a filename, strip it down to the module name
-    if os.path.isfile(name):
-        basename = os.path.basename(name)
-        name = os.path.splitext(basename)[0]
-
+    name,abs_path = get_name(name,abs_path=None)
     bp_name = f"{name}_bp"
     logger  = get_logFile(bp_name)
     logger.info(f"Python path: {sys.path!r}")
-    abs_path = abs_path or __name__
     # build up only the kwargs they actually gave us
-
     bp = Blueprint(
         bp_name,
         abs_path,
@@ -91,3 +98,25 @@ def addHandler(app,name=None):
         finally:
             sys.path.pop(0)
     return app
+def register_bps(app,bp_list):
+    for bp in bp_list:
+        app.register_blueprint(bp)
+    return app
+def get_Flask_app(*args,**kwargs):
+    """Quart app factory."""
+    keys = ['name','bp_list']
+    values , kwargs = get_from_kwargs(keys,**kwargs)
+    name = values.get('name')
+    bp_list = values.get('bp_list')
+    for arg in args:
+        if not name and not isinstance(arg,list):
+            name = arg
+        elif not bp_list:
+            bp_list = arg
+    bp_list = bp_list or []
+    name,abs_path = get_name(name)
+    app = Flask(name,**kwargs)
+    app = addHandler(app,name=name)
+    app = register_bps(app,bp_list)
+    return app
+
